@@ -4,12 +4,12 @@ jQuery(function($) {
         placeholder: 'ui-state-highlight',
         forcePlaceholderSize: 'true',
         items: 'div.inline-related',
-        update: update
+        update: updateInlineOrder
     });
     $("#cyclope-relatedcontent-self_type-self_id-group, #question_set-group").disableSelection();
 });
 
-function update() {
+function updateInlineOrder() {
     $(this).find('div.inline-related').each(function(i) {
             $(this).find('input[id$=order]').val(i+1);
     });
@@ -24,3 +24,20 @@ jQuery(document).ready(function($){
     });
 });
 
+
+jQuery(function($) {
+    $("body.categorizations-changelist table#result_list").sortable({
+        forcePlaceholderSize: 'true',
+        items:'tr:gt(0)',
+        update: updateChangelistOrder
+    });
+    $('body.categorizations-changelist input[id$=order]').css('display', 'none');
+    $('body.categorizations-changelist input[id$=order]').after("<div class='order-arrow'>↕</div>");
+    $("body.categorizations-changelist table#result_list").disableSelection();
+});
+
+function updateChangelistOrder(event, ui) {
+    $('input[id$=order]').each(function (i, elem){
+        $(elem).val(i+1);
+    });
+};
