@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
+# Copyright 2010-2013 Código Sur Sociedad Civil.
 # All rights reserved.
 #
 # This file is part of Cyclope.
@@ -55,7 +55,7 @@ from django.db.models.signals import post_save
 from django.core.exceptions import ImproperlyConfigured
 from django.db.utils import DatabaseError
 
-from cyclope.models import SiteSettings
+from cyclope.models import SiteSettings, DesignSettings
 
 from cyclope.core.frontend.sites import site
 
@@ -177,3 +177,4 @@ def _refresh_site_settings(sender, instance, created, **kwargs):
         reload(sys.modules[__name__])
 
 post_save.connect(_refresh_site_settings, sender=SiteSettings)
+post_save.connect(_refresh_site_settings, sender=DesignSettings)
